@@ -156,6 +156,7 @@ typedef enum {
 	CD_SENSOR_KIND_COLORHUG,	/* Since: 0.1.15 */
 	CD_SENSOR_KIND_SPYDER2,		/* Since: 0.1.16 */
 	CD_SENSOR_KIND_SPYDER3,		/* Since: 0.1.16 */
+	CD_SENSOR_KIND_COLORHUG_SPECTRO,/* Since: 0.1.24 */
 	CD_SENSOR_KIND_LAST
 } CdSensorKind;
 
@@ -187,6 +188,7 @@ typedef enum {
 	CD_SENSOR_STATE_STARTING,
 	CD_SENSOR_STATE_IDLE,
 	CD_SENSOR_STATE_MEASURING,
+	CD_SENSOR_STATE_BUSY,		/* Since: 0.1.19 */
 	CD_SENSOR_STATE_LAST
 } CdSensorState;
 
@@ -273,6 +275,7 @@ typedef enum {
 #define CD_DEVICE_PROPERTY_ID			"DeviceId"
 #define CD_DEVICE_PROPERTY_SCOPE		"Scope"
 #define CD_DEVICE_PROPERTY_OWNER		"Owner"
+#define CD_DEVICE_PROPERTY_SEAT			"Seat"
 #define CD_DEVICE_PROPERTY_PROFILING_INHIBITORS	"ProfilingInhibitors"
 
 const gchar	*cd_device_kind_to_string		(CdDeviceKind		 kind_enum);
