@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2010-2011 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2010-2012 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -74,6 +74,7 @@ struct _CdDevicePrivate
 	gboolean			 is_virtual;
 	GHashTable			*metadata;
 	guint				 owner;
+	gchar				*seat;
 };
 
 enum {
@@ -147,6 +148,26 @@ cd_device_set_owner (CdDevice *device, guint owner)
 	device->priv->owner = owner;
 }
 
+/**
+ * cd_device_get_seat:
+ **/
+const gchar *
+cd_device_get_seat (CdDevice *device)
+{
+	g_return_val_if_fail (CD_IS_DEVICE (device), NULL);
+	return device->priv->seat;
+}
+
+/**
+ * cd_device_set_seat:
+ **/
+void
+cd_device_set_seat (CdDevice *device, const gchar *seat)
+{
+	g_return_if_fail (CD_IS_DEVICE (device));
+	device->priv->seat = g_strdup (seat);
+}
+
 /**
  * cd_device_mode_to_string:
  **/
@@ -244,19 +265,21 @@ cd_device_set_object_path (CdDevice *device)
 	gchar *path_owner;
 	struct passwd *pw;
 
-	/* make sure object path is sane */
-	path_tmp = cd_main_ensure_dbus_path (device->priv->id);
-
 	/* append the uid to the object path */
 	pw = getpwuid (device->priv->owner);
 	if (device->priv->owner == 0 ||
 	    g_strcmp0 (pw->pw_name, DAEMON_USER) == 0) {
-		path_owner = g_strdup (path_tmp);
+		path_tmp = g_strdup (device->priv->id);
 	} else {
-		path_owner = g_strdup_printf ("%s_%s",
-					      path_tmp,
-					      pw->pw_name);
+		path_tmp = g_strdup_printf ("%s_%s_%d",
+					    device->priv->id,
+					    pw->pw_name,
+					    device->priv->owner);
 	}
+
+	/* make sure object path is sane */
+	path_owner = cd_main_ensure_dbus_path (path_tmp);
+
 	device->priv->object_path = g_build_filename (COLORD_DBUS_PATH,
 						      "devices",
 						      path_owner,
@@ -832,6 +855,17 @@ cd_device_set_model (CdDevice *device, const gchar *model)
 	priv->model = g_string_free (tmp, FALSE);
 }
 
+/**
+ * cd_device_get_nullable_for_string:
+ **/
+static GVariant *
+cd_device_get_nullable_for_string (const gchar *value)
+{
+	if (value == NULL)
+		return g_variant_new_string ("");
+	return g_variant_new_string (value);
+}
+
 /**
  * cd_device_set_property_internal:
  **/
@@ -867,6 +901,9 @@ cd_device_set_property_internal (CdDevice *device,
 	} else if (g_strcmp0 (property, CD_DEVICE_PROPERTY_MODE) == 0) {
 		g_free (priv->mode);
 		priv->mode = g_strdup (value);
+	} else if (g_strcmp0 (property, CD_DEVICE_PROPERTY_SEAT) == 0) {
+		g_free (priv->seat);
+		priv->seat = g_strdup (value);
 	} else {
 		/* add to metadata */
 		is_metadata = TRUE;
@@ -890,7 +927,7 @@ cd_device_set_property_internal (CdDevice *device,
 	if (!is_metadata) {
 		cd_device_dbus_emit_property_changed (device,
 						      property,
-						      g_variant_new_string (value));
+						      cd_device_get_nullable_for_string (value));
 	}
 	return ret;
 }
@@ -1340,17 +1377,6 @@ cd_device_inhibit_changed_cb (CdInhibit *inhibit,
 	cd_device_dbus_emit_device_changed (device);
 }
 
-/**
- * cd_device_get_nullable_for_string:
- **/
-static GVariant *
-cd_device_get_nullable_for_string (const gchar *value)
-{
-	if (value == NULL)
-		return g_variant_new_string ("");
-	return g_variant_new_string (value);
-}
-
 /**
  * cd_device_dbus_get_property:
  **/
@@ -1432,6 +1458,10 @@ cd_device_dbus_get_property (GDBusConnection *connection_, const gchar *sender,
 		retval = g_variant_new_uint32 (priv->owner);
 		goto out;
 	}
+	if (g_strcmp0 (property_name, CD_DEVICE_PROPERTY_SEAT) == 0) {
+		retval = cd_device_get_nullable_for_string (priv->seat);
+		goto out;
+	}
 	if (g_strcmp0 (property_name, CD_DEVICE_PROPERTY_PROFILING_INHIBITORS) == 0) {
 		bus_names = cd_inhibit_get_bus_names (priv->inhibit);
 		retval = g_variant_new_strv ((const gchar * const *) bus_names, -1);
@@ -1667,6 +1697,7 @@ cd_device_finalize (GObject *object)
 	g_free (priv->mode);
 	g_free (priv->serial);
 	g_free (priv->kind);
+	g_free (priv->seat);
 	g_free (priv->object_path);
 	g_ptr_array_unref (priv->profiles);
 	g_object_unref (priv->profile_array);
