@@ -171,19 +171,21 @@ cd_profile_set_object_path (CdProfile *profile)
 	gchar *path_owner;
 	struct passwd *pw;
 
-	/* make sure object path is sane */
-	path_tmp = cd_main_ensure_dbus_path (profile->priv->id);
 
 	/* append the uid to the object path */
 	pw = getpwuid (profile->priv->owner);
 	if (profile->priv->owner == 0 ||
 	    g_strcmp0 (pw->pw_name, DAEMON_USER) == 0) {
-		path_owner = g_strdup (path_tmp);
+		path_tmp = g_strdup (profile->priv->id);
 	} else {
-		path_owner = g_strdup_printf ("%s_%s",
-					      path_tmp,
-					      pw->pw_name);
+		path_tmp = g_strdup_printf ("%s_%s_%d",
+					    profile->priv->id,
+					    pw->pw_name,
+					    profile->priv->owner);
 	}
+	/* make sure object path is sane */
+	path_owner = cd_main_ensure_dbus_path (path_tmp);
+
 	profile->priv->object_path = g_build_filename (COLORD_DBUS_PATH,
 						       "profiles",
 						       path_owner,
