@@ -39,6 +39,7 @@ struct _CdSensorClientPrivate
 {
 	GUdevClient			*gudev_client;
 	GPtrArray			*array_sensors;
+	guint				 idx;
 };
 
 enum {
@@ -92,6 +93,9 @@ cd_sensor_client_add (CdSensorClient *sensor_client,
 		goto out;
 	}
 
+	/* set the index */
+	cd_sensor_set_index (sensor, sensor_client->priv->idx);
+
 	/* load the sensor */
 	ret = cd_sensor_load (sensor, &error);
 	if (!ret) {
@@ -104,6 +108,7 @@ cd_sensor_client_add (CdSensorClient *sensor_client,
 	/* signal the addition */
 	g_debug ("emit: added");
 	g_signal_emit (sensor_client, signals[SIGNAL_SENSOR_ADDED], 0, sensor);
+	sensor_client->priv->idx++;
 
 	/* keep track so we can remove with the same device */
 	g_ptr_array_add (sensor_client->priv->array_sensors, g_object_ref (sensor));
@@ -122,7 +127,7 @@ cd_sensor_client_remove (CdSensorClient *sensor_client,
 {
 	CdSensor *sensor;
 	const gchar *device_file;
-	const gchar *id;
+	const gchar *device_path;
 	gboolean ret;
 	guint i;
 
@@ -137,12 +142,12 @@ cd_sensor_client_remove (CdSensorClient *sensor_client,
 		goto out;
 
 	/* get data */
-	g_debug ("removing color management device: %s",
-		 g_udev_device_get_sysfs_path (device));
-	id = g_udev_device_get_property (device, "COLORD_SENSOR_KIND");
+	device_path = g_udev_device_get_sysfs_path (device);
+	g_debug ("removing color management device: %s [%s]",
+		 device_path, device_file);
 	for (i=0; i<sensor_client->priv->array_sensors->len; i++) {
 		sensor = g_ptr_array_index (sensor_client->priv->array_sensors, i);
-		if (g_strcmp0 (cd_sensor_get_id (sensor), id) == 0) {
+		if (g_strcmp0 (cd_sensor_get_device_path (sensor), device_path) == 0) {
 			g_debug ("emit: removed");
 			g_signal_emit (sensor_client, signals[SIGNAL_SENSOR_REMOVED], 0, sensor);
 			g_ptr_array_remove_index_fast (sensor_client->priv->array_sensors, i);
